@@ -312,7 +312,7 @@ bool SessionImpl::GetSessionValue(const string& sectionName, const string& value
   // try special values, part 2
   if (!haveValue && Utils::EqualsIgnoreCase(valueName, CFG_MACRO_NAME_BINDIR))
   {
-    value = SessionImpl::GetSession()->GetSpecialPath(SpecialPath::BinDirectory).ToString();
+    value = SESSION_IMPL()->GetSpecialPath(SpecialPath::BinDirectory).ToString();
     haveValue = true;
   }
   else if (!haveValue && Utils::EqualsIgnoreCase(valueName, CFG_MACRO_NAME_PROGNAME))
@@ -336,13 +336,13 @@ bool SessionImpl::GetSessionValue(const string& sectionName, const string& value
 #endif
   else if (!haveValue && Utils::EqualsIgnoreCase(valueName, CFG_MACRO_NAME_LOCALFONTDIRS))
   {
-    value = StringUtil::Flatten(SessionImpl::GetSession()->GetFontDirectories(), PathNameUtil::PathNameDelimiter);
+    value = StringUtil::Flatten(SESSION_IMPL()->GetFontDirectories(), PathNameUtil::PathNameDelimiter);
     haveValue = true;
   }
   else if (!haveValue && Utils::EqualsIgnoreCase(valueName, CFG_MACRO_NAME_PSFONTDIRS))
   {
     string psFontDirs;
-    if (SessionImpl::GetSession()->GetPsFontDirs(psFontDirs))
+    if (SESSION_IMPL()->GetPsFontDirs(psFontDirs))
     {
       value = psFontDirs;
       haveValue = true;
@@ -351,7 +351,7 @@ bool SessionImpl::GetSessionValue(const string& sectionName, const string& value
   else if (!haveValue && Utils::EqualsIgnoreCase(valueName, CFG_MACRO_NAME_TTFDIRS))
   {
     string ttfDirs;
-    if (SessionImpl::GetSession()->GetTTFDirs(ttfDirs))
+    if (SESSION_IMPL()->GetTTFDirs(ttfDirs))
     {
       value = ttfDirs;
       haveValue = true;
@@ -360,7 +360,7 @@ bool SessionImpl::GetSessionValue(const string& sectionName, const string& value
   else if (!haveValue && Utils::EqualsIgnoreCase(valueName, CFG_MACRO_NAME_OTFDIRS))
   {
     string otfDirs;
-    if (SessionImpl::GetSession()->GetOTFDirs(otfDirs))
+    if (SESSION_IMPL()->GetOTFDirs(otfDirs))
     {
       value = otfDirs;
       haveValue = true;
@@ -502,9 +502,13 @@ void SessionImpl::SetAdminMode(bool adminMode, bool force)
   {
     return;
   }
-  if (adminMode && !force && !IsSharedSetup())
+  if (adminMode && initStartupConfig.isSharedSetup != TriState::True)
   {
-    MIKTEX_FATAL_ERROR(T_("Administrator mode cannot be enabled (makes no sense) because this is not a shared MiKTeX setup."));
+    if (!force)
+    {
+      MIKTEX_FATAL_ERROR(T_("Administrator mode cannot be enabled (makes no sense) because this is not a shared MiKTeX setup."));
+    }
+    initStartupConfig.isSharedSetup = TriState::True;
   }
   trace_config->WriteLine("core", TraceLevel::Info, fmt::format(T_("turning {0} administrator mode"), (adminMode ? "on" : "off")));
   // reinitialize
