@@ -128,6 +128,7 @@ double paper_height             = 842.0;
 static double x_offset          = 72.0;
 static double y_offset          = 72.0;
 int    landscape_mode           = 0;
+int    dvi_ptex_with_vert       = 0;
 static int    translate_origin  = 0;
 
 static int has_paper_option = 0;
@@ -217,11 +218,13 @@ show_usage (void)
   printf ("  -g dimension\tAnnotation \"grow\" amount [0.0in]\n");
   printf ("  -h | --help \tShow this help message and exit\n");
   printf ("  -i cfgfile\tRead additional configuration file\t\n");
+  printf ("  --kpathsea-debug number\tSet kpathsea debugging flags [0]\n");
   printf ("  -l \t\tLandscape mode\n");
   printf ("  -m number\tSet additional magnification [1.0]\n");
   printf ("  --mvorigin\tTranslate the origin for MP inclusion\n");
   printf ("  -o filename\tSet output file name, \"-\" for stdout [DVIFILE.pdf]\n");
   printf ("  -p papersize\tSet papersize [a4]\n");
+  printf ("  --pdfm-str-utf8\tAssume PDFMark strings are encoded in UTF-8\n");
   printf ("  -q \t\tBe quiet\n");
   printf ("  -r resolution\tSet resolution (in DPI) for raster fonts [600]\n");
   printf ("  -s pages\tSelect page ranges [all pages]\n");
@@ -230,7 +233,6 @@ show_usage (void)
   printf ("  --version\tOutput version information and exit\n");
   printf ("  -v \t\tBe verbose\n");
   printf ("  -vv\t\tBe more verbose\n");
-  printf ("  --kpathsea-debug number\tSet kpathsea debugging flags [0]\n");
   printf ("  -x dimension\tSet horizontal offset [1.0in]\n");
   printf ("  -y dimension\tSet vertical offset [1.0in]\n");
   printf ("  -z number  \tSet zlib compression level (0-9) [9]\n");
@@ -442,6 +444,7 @@ static struct option long_options[] = {
   {"dvipdfm", 0, 0, 132},
   {"mvorigin", 0, 0, 1000},
   {"kpathsea-debug", 1, 0, 133},
+  {"pdfm-str-utf8", 0, 0, 134},
   {0, 0, 0, 0}
 };
 
@@ -476,6 +479,10 @@ do_args_first_pass (int argc, char *argv[], const char *source, int unsafe)
       kpathsea_debug = atoi(optarg);
       break;
 
+    case 134: /* --pdfm-str-utf8 */
+      dpx_conf.pdfm_str_utf8 = 1;
+      break;
+
     case 1000: /* --mvorigin */
       translate_origin = 1;
       break;
@@ -541,7 +548,7 @@ do_args_second_pass (int argc, char *argv[], const char *source, int unsafe)
   optind = 1;
   while ((c = getopt_long(argc, argv, optstrig, long_options, NULL)) != -1) {
     switch(c) {
-    case 'h': case 130: case 131: case 132: case 133: case 1000: case 'q': case 'v': case 'M': /* already done */
+    case 'h': case 130: case 131: case 132: case 133: case 134: case 1000: case 'q': case 'v': case 'M': /* already done */
       break;
 
     /* 'm' option handled in first_pass */
