@@ -2,7 +2,7 @@
 ** FontCache.cpp                                                        **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2021 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2022 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -297,9 +297,9 @@ bool FontCache::fontinfo (const string &dirname, vector<FontInfo> &infos, vector
 				ifstream ifs(path, ios::binary);
 #endif
 				if (fontinfo(ifs, info))
-					infos.emplace_back(move(info));
+					infos.push_back(move(info));
 				else
-					invalid.emplace_back(fname.substr(1));
+					invalid.push_back(fname.substr(1));
 			}
 		}
 	}
