@@ -2,7 +2,7 @@
 ** PapersizeSpecialHandler.cpp                                          **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2020 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2022 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -58,7 +58,7 @@ void PapersizeSpecialHandler::storePaperSize (unsigned pageno, Length width, Len
 		if (!_pageSizes.empty() && _pageSizes.back().first == pageno)
 			_pageSizes.back().second = whpair;
 		else
-			_pageSizes.emplace_back(PageSize(pageno, whpair));
+			_pageSizes.emplace_back(pageno, whpair);
 	}
 }
 
