@@ -1,6 +1,39 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="sl_SI">
+<context>
+    <name>GuidelineEditDialog</name>
+    <message>
+        <location filename="../src/GuidelineEditDialog.ui" line="14"/>
+        <source>Edit guideline...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/GuidelineEditDialog.ui" line="22"/>
+        <source>Page:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/GuidelineEditDialog.ui" line="36"/>
+        <source>Position:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/GuidelineEditDialog.ui" line="53"/>
+        <source>cm</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/GuidelineEditDialog.ui" line="58"/>
+        <source>in</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/GuidelineEditDialog.ui" line="63"/>
+        <source>bp</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>PaperSize</name>
     <message>
@@ -719,12 +752,12 @@
 <context>
     <name>QtPDF</name>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="1269"/>
+        <location filename="../src/PDFDocumentView.cpp" line="33"/>
         <source>[language name]</source>
         <translation type="unfinished">slovenščino</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="1270"/>
+        <location filename="../src/PDFDocumentView.cpp" line="34"/>
         <source>[translator&apos;s name/email]</source>
         <translation type="unfinished">&lt;a href=&quot;mailto:mojca.miklavec.lists@gmail.com&quot;&gt;Mojca Miklavec&lt;/a&gt;</translation>
     </message>
@@ -737,32 +770,32 @@
         <translation>izris strani</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2019"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2029"/>
         <source>Unlock PDF</source>
         <translation>Odklep datoteke PDF</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2019"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2029"/>
         <source>Please enter the password to unlock the PDF</source>
         <translation>Vnesite geslo za odklep datoteke PDF</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2035"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2045"/>
         <source>Incorrect password</source>
         <translation>Nepravilno geslo</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2035"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2045"/>
         <source>The password you entered was incorrect.</source>
         <translation>Geslo, ki ste ga vpisali, ni pravilno.</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2041"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2051"/>
         <source>This document is locked. You need a password to open it.</source>
         <translation>Dokument je zaklenjen. Za odklep potrebujete geslo.</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2042"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2052"/>
         <source>Unlock</source>
         <translation>Odkleni</translation>
     </message>
@@ -780,332 +813,332 @@
         <translation>Kopiranje besedila iz tega dokumenta ni dovoljeno.</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2587"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2597"/>
         <source>Goto page %1</source>
         <translatorcomment>morda raje kar &apos;Na stran %1&apos;</translatorcomment>
         <translation type="unfinished">Pojdi na stran %1</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2599"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2609"/>
         <source>Execute `%1`</source>
         <translation type="unfinished">Izvedi `%1`</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2845"/>
-        <location filename="../src/PDFDocumentView.cpp" line="2862"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2855"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2872"/>
         <source>Table of Contents</source>
         <translatorcomment>Vsebina</translatorcomment>
         <translation type="unfinished">Kazalo</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2954"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3161"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2964"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3171"/>
         <source>Meta Data</source>
         <translation type="unfinished">Meta podatki</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3010"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3171"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3020"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3181"/>
         <source>Processing</source>
         <translation type="unfinished">Obdelujem</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3042"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3178"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3052"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3188"/>
         <source>Other</source>
         <translatorcomment>Drugo</translatorcomment>
         <translation type="unfinished">Ostalo</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3067"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3077"/>
         <source>B</source>
         <extracomment>File size: bytes</extracomment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3069"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3079"/>
         <source>kB</source>
         <extracomment>File size: kilobytes</extracomment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3071"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3081"/>
         <source>MB</source>
         <extracomment>File size: megabytes</extracomment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3073"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3083"/>
         <source>GB</source>
         <extracomment>File size: gigabytes</extracomment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3075"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3085"/>
         <source>TB</source>
         <extracomment>File size: terabytes</extracomment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3105"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3115"/>
         <source>Yes</source>
         <translation>Da</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3108"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3118"/>
         <source>No</source>
         <translation>Ne</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3111"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3148"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3121"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3158"/>
         <source>Unknown</source>
         <translation type="unfinished">Neznano</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3163"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3173"/>
         <source>Document</source>
         <translation>Dokument</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3164"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3174"/>
         <source>Title:</source>
         <translation>Naslov:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3165"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3175"/>
         <source>Author:</source>
         <translation>Avtor:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3166"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3176"/>
         <source>Subject:</source>
         <translation type="unfinished">Zadeva:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3167"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3177"/>
         <source>Keywords:</source>
         <translation>Ključne besede:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3168"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3178"/>
         <source>Page size:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3169"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3179"/>
         <source>File size:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3172"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3182"/>
         <source>Creator:</source>
         <translatorcomment>Program, ki je ustvaril dokument, kreator, ...?</translatorcomment>
         <translation type="unfinished">Ustvarjeno z:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3173"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3183"/>
         <source>Producer:</source>
         <translatorcomment>Program, ki je stavil dokument, &apos;producent&apos;, ...? (Običajno knjižnica.)</translatorcomment>
         <translation type="unfinished">Sestavljeno z:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3174"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3184"/>
         <source>Creation date:</source>
         <translation>Datum nastanka:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3175"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3185"/>
         <source>Modification date:</source>
         <translation type="unfinished">Zadnje spremembe:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3176"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3186"/>
         <source>Trapped:</source>
         <translatorcomment>Postopek prekrivanja sosednje ležečih polno potiskanih površin, s katerimi se izognemo napakam zaradi neskladja barvnih izvlečkov v tisku CMYK. Trapping je proces, ki barvne izvlečke tako prilagodi, da se na končnem odtisu izognemo vidnim napakam zaradi tehničnih omejitev tiskanja. (Tehnologija grafičnih procesov, NTF)</translatorcomment>
         <translation type="unfinished">Barvno prekrivanje:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3187"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3281"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3197"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3291"/>
         <source>Fonts</source>
         <translation>Pisave</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3237"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3247"/>
         <source>Type 0</source>
         <translation>Type 0</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3240"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3250"/>
         <source>Type 1</source>
         <translation>Type 1</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3243"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3253"/>
         <source>Type 1 (multiple master)</source>
         <translation>Type 1 (multiple master)</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3246"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3256"/>
         <source>Type 3</source>
         <translation>Type 3</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3249"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3259"/>
         <source>TrueType</source>
         <translation>TrueType</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3252"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3262"/>
         <source>yes</source>
         <translation>da</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3252"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3262"/>
         <source>no</source>
         <translation>ne</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3255"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3265"/>
         <source>[embedded]</source>
         <translatorcomment>ali so pisave vključene v dokumentu</translatorcomment>
         <translation type="unfinished">[vključene v dokument]</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3258"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3268"/>
         <source>[builtin]</source>
         <translatorcomment>standardne pisave, ki niso dodane v dokument, pač pa so del pregledovalnika</translatorcomment>
         <translation type="unfinished">[vgrajene]</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3282"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3292"/>
         <source>Name</source>
         <translation>Ime</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3282"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3292"/>
         <source>Type</source>
         <translation>Vrsta</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3282"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3292"/>
         <source>Subset</source>
         <translatorcomment>Potreben je boljši prevod za &apos;font subsetting&apos;</translatorcomment>
         <translation type="unfinished">Podmnožica</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3282"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3292"/>
         <source>Source</source>
         <translatorcomment>Kaj je &apos;source&apos; pri pisavah?</translatorcomment>
         <translation type="unfinished">Izvor</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3290"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3385"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3300"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3395"/>
         <source>Permissions</source>
         <translation type="unfinished">Dovoljenja</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3339"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3348"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3357"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3364"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3369"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3349"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3358"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3367"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3374"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3379"/>
         <source>Allowed</source>
         <translation type="unfinished">Dovoljeno</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3341"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3351"/>
         <source>Low resolution only</source>
         <translatorcomment>ali je dovoljeno tiskati</translatorcomment>
         <translation>Samo v nizki resoluciji</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3344"/>
         <location filename="../src/PDFDocumentView.cpp" line="3354"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3361"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3366"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3364"/>
         <location filename="../src/PDFDocumentView.cpp" line="3371"/>
         <location filename="../src/PDFDocumentView.cpp" line="3376"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3377"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3378"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3379"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3380"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3381"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3386"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3387"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3388"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3389"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3390"/>
         <source>Denied</source>
         <translation type="unfinished">Zavrnjeno</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3350"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3360"/>
         <source>Assembling only</source>
         <translatorcomment>ali je dovoljeno spreminjati dokument PDF</translatorcomment>
         <translation type="unfinished">Samo sestavljanje dokumenta</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3351"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3361"/>
         <source>Insert, rotate, or delete pages and create bookmarks or thumbnail images</source>
         <translatorcomment>ali je dovoljeno spreminjati dokument PDF</translatorcomment>
         <translation type="unfinished">Vstavljanje, rotacija ali izbris strani, dodajanje zaznamkov ali predoglednih sličic</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3359"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3369"/>
         <source>Accessibility support only</source>
         <translation type="unfinished">Samo podpora dostopnosti</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3387"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3397"/>
         <source>Printing:</source>
         <translatorcomment>dovoljenja</translatorcomment>
         <translation>Tiskanje:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3388"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3398"/>
         <source>Modifications:</source>
         <translatorcomment>dovoljenja</translatorcomment>
         <translation>Spremembe:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3389"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3399"/>
         <source>Extraction:</source>
         <translatorcomment>dovoljenja</translatorcomment>
         <translation type="unfinished">Izvleček strani:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3390"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3400"/>
         <source>Annotation:</source>
         <translatorcomment>dovoljenja</translatorcomment>
         <translation type="unfinished">Dodajanje opomb:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3391"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3401"/>
         <source>Filling forms:</source>
         <translatorcomment>dovoljenja</translatorcomment>
         <translation type="unfinished">Izpolnjevanje obrazcev:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3399"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3491"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3409"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3501"/>
         <source>Annotations</source>
         <translation>Opombe</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3492"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3502"/>
         <source>Page</source>
         <translation>Stran</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3492"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3502"/>
         <source>Subject</source>
         <translatorcomment>Zadeva, predmet, ...?</translatorcomment>
         <translation type="unfinished">Naslov</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3492"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3502"/>
         <source>Author</source>
         <translation>Avtor</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3492"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3502"/>
         <source>Contents</source>
         <translation>Vsebina</translation>
     </message>
