@@ -1,6 +1,6 @@
 /*
 	This is part of TeXworks, an environment for working with TeX documents
-	Copyright (C) 2007-2021  Jonathan Kew, Stefan Löffler, Charlie Sharpsteen
+	Copyright (C) 2007-2022  Jonathan Kew, Stefan Löffler, Charlie Sharpsteen
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -22,6 +22,8 @@
 #ifndef TWApp_H
 #define TWApp_H
 
+#include "utils/TypesetManager.h"
+
 #include <QAction>
 #include <QApplication>
 #include <QClipboard>
@@ -107,6 +109,8 @@ public:
 
 	static QStringList getTranslationList();
 
+	Tw::Utils::TypesetManager & typesetManager() { return m_typesetManager; }
+
 	TWScriptManager* getScriptManager() { return scriptManager; }
 
 #if defined(Q_OS_WIN)
@@ -259,6 +263,8 @@ private:
 
 	QHash<QString, QVariant> m_globals;
 
+	Tw::Utils::TypesetManager m_typesetManager{this};
+
 	static TWApp *theAppInstance;
 };
 
